@@ -10,4 +10,9 @@ thread_output_directory: str = None
 plugin_decompiler_enable_pycdc = False
 plugin_decompiler_enable_uncompyle6 = False
 
-decompile_file:Dict = None # only decompile_file in this filename , if set to `None` ,all fit files will be decompile
\ No newline at end of file
+decompile_file:Dict = None # only decompile_file in this filename , if set to `None` ,all fit files will be decompile
+
+
+
+############# DEBUG
+DEBUG_TestPycDump = False
