@@ -4,11 +4,13 @@ import os
 import shutil
 import time
 from typing import List
-from .. import configuration
+from .. import configuration, pyc_checker
+from ..pyc_checker.pyc import PycHandler
 from ..py_package import PackageStruct, PackageDescription
 from PyInstaller.utils.cliutils.archive_viewer import get_archive, get_data, get_content, get_archive_content
 from ..utils.banner import print_banner
 
+
 class CommonDump():
 
     @property
@@ -96,9 +98,13 @@ class CommonDump():
             return
         self.global_start_time = time.time()
 
-    def main(self, target_file: str, output_directory: str, thread: int = 0, timeout: int = 10, target_file_type: str = None, session_timeout: int = 120, plugin: List = [], decompile_file: List = None, **args):
+    def main(self, target_file: str, output_directory: str, thread: int = 0, timeout: int = 10, target_file_type: str = None, session_timeout: int = 120, plugin: List = [], decompile_file: List = None, struct_headers: str = None, **args):
         self.statistics_status()
         print_banner()
+        if struct_headers:
+            pyc_header = bytes.fromhex(struct_headers.replace(' ', ''))
+            pyc_checker.default_pyc = PycHandler(pyc_header)
+
         configuration.thread_count = thread  # thread
         configuration.thread_timeout = timeout
         configuration.thread_output_directory = output_directory
@@ -106,6 +112,9 @@ class CommonDump():
         configuration.decompile_file = dict(
             zip(decompile_file, [True for x in decompile_file])) if decompile_file else None
         self.load_plugins(plugin)
+        if not target_file:
+            print('[!] target_file is required')
+            return
         os.chdir(os.path.dirname(target_file))
         print(f'[*] target file input:{target_file}\nto:{output_directory}')
 
