@@ -28,7 +28,7 @@ def run():
         default=0,
         type=int,
         dest='thread',
-        help='thread count for running (default: %(default)s) cpu-count * 2.',
+        help='thread count for running (default: %(default)s) cpu-count * 8.',
     )
 
     parser.add_argument(
@@ -65,7 +65,14 @@ def run():
         dest='decompile_file',
         help='only decompile referred file for quick complete (default: %(default)s).',
     )
-
+    parser.add_argument(
+        '--header',
+        nargs=argparse.ZERO_OR_MORE,
+        default=None,
+        dest='struct_headers',
+        help='specify pyc header hex-string (default: %(default)s).if not set , pydumpck will use struct.pyc\'s header(if possible) and default header.eg:6f0d0d0a 00000000 00000000 ffffffff',
+    )
+    
     parser.add_argument(
         '-v',
         '--version',
@@ -86,8 +93,9 @@ def run():
     )
     args = parser.parse_args()
     if not args.show_version == False:
-        print(__version__.__version__)
-        return
+        v = __version__.__version__
+        print(v)
+        return v
     print(parser.description)
     print('-' * 20)
     print(f'[+] pydumpck initilizing with {__version__.__version__}')
